package com.zhilian.mybatis_plus.controller;

import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.web.controller.BaseController;
import com.zhilian.common.core.web.page.TableDataInfo;
import com.zhilian.common.log.enums.BusinessType;
import com.zhilian.common.security.annotation.RequiresPermissions;
import com.zhilian.common.security.utils.SecurityUtils;
import com.zhilian.mybatis_plus.domain.Clazz;
import com.zhilian.mybatis_plus.service.ClazzService;
import com.zhilian.common.log.annotation.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * @version:
 * @Author: Seer
 * @description:
 * @date: 2024/3/24  10:45
 */
@RestController
@RequestMapping("/clazz")
public class ClazzController extends BaseController{

    @Autowired
    private ClazzService clazzService;


    /**
     * 查询班级列表
     * @param clazz
     * @return
     */
    @GetMapping("/list")
    public Result<TableDataInfo<Clazz>> list (Clazz clazz) {
        startPage();
        List<Clazz> list = clazzService.pageQuery(clazz);
        return getDataTable(list);
    }

    /**
     * 新增班级
     * @param clazz
     * @return
     */
    @Log(title = "班级管理", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add (@Validated @RequestBody Clazz clazz) {
        if (!clazzService.checkConfigKeyUnique(clazz)) {
            return error("新增参数'" + clazz.getName() + "'失败，班级名称已存在");
        }
        clazz.setCreateBy(SecurityUtils.getUsername());
        return toAjax(clazzService.save(clazz));
    }

    /**
     * 修改班级
     */
    @Log(title = "班级管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit (@Validated @RequestBody Clazz clazz) {
        if (!clazzService.checkConfigKeyUnique(clazz)) {
            return error("修改参数'" + clazz.getName() + "'失败，班级名称已存在");
        }
        clazz.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(clazzService.updateById(clazz));
    }


    /**
     * 删除班级
     */
    @RequiresPermissions("system:config:remove")
    @Log(title = "班级管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{clazzIds}")
    public Result remove (@PathVariable Long[] clazzIds) {
        clazzService.removeBatchByIds(Arrays.asList(clazzIds));
        return success();
    }



}
