package com.zhilian.mybatis_plus.controller;

import com.zhilian.common.core.domain.Result;
import com.zhilian.common.core.web.controller.BaseController;
import com.zhilian.common.core.web.page.TableDataInfo;
import com.zhilian.common.log.annotation.Log;
import com.zhilian.common.log.enums.BusinessType;
import com.zhilian.common.security.annotation.RequiresPermissions;
import com.zhilian.common.security.utils.SecurityUtils;
import com.zhilian.mybatis_plus.domain.Student;
import com.zhilian.mybatis_plus.domain.response.StudentRes;
import com.zhilian.mybatis_plus.service.StudentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * @version:
 * @Author: LiYuan
 * @description:
 * @date: 2024/3/25  15:12
 */
@RestController
@RequestMapping("/student")
public class StudentController extends BaseController {

    @Autowired
    private StudentService studentService;

    /**
     * 查询学生列表
     * @param student
     * @return
     */
    @GetMapping("/list")
    public Result<TableDataInfo<StudentRes>> list (Student student) {
        startPage();
        List<StudentRes> list = studentService.pageQuery(student);
        return getDataTable(list);
    }

    /**
     * 新增学生
     * @param student
     * @return
     */
    @Log(title = "学生管理", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add (@Validated @RequestBody Student student) {
        if (!studentService.checkConfigKeyUnique(student)) {
            return error("新增参数'" + student.getName() + "'失败，学生名称已存在");
        }
        student.setCreateBy(SecurityUtils.getUsername());
        return toAjax(studentService.save(student));
    }

    /**
     * 修改学生
     */
    @Log(title = "班级管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit (@Validated @RequestBody Student student) {
        if (!studentService.checkConfigKeyUnique(student)) {
            return error("修改参数'" + student.getName() + "'失败，学生名称已存在");
        }
        student.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(studentService.updateById(student));
    }


    /**
     * 删除学生
     */
    @RequiresPermissions("system:config:remove")
    @Log(title = "学生管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{studentIds}")
    public Result remove (@PathVariable Long[] studentIds) {
        studentService.removeBatchByIds(Arrays.asList(studentIds));
        return success();
    }


}
