package com.zhilian.mybatis_plus.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhilian.common.core.utils.StringUtils;
import com.zhilian.mybatis_plus.domain.Clazz;
import com.zhilian.mybatis_plus.mapper.ClazzMapper;
import com.zhilian.mybatis_plus.service.ClazzService;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.function.Function;

/**
 * @version:
 * @Author: Seer
 * @description:
 * @date: 2024/3/24  10:46
 */
@Service
public class ClazzServiceImpl extends ServiceImpl<ClazzMapper,Clazz> implements ClazzService {

    /**
     * 查询班级列表
     * @param clazz
     * @return
     */
    @Override
    public List<Clazz> pageQuery(Clazz clazz) {
        LambdaQueryWrapper<Clazz> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(clazz.getName())){
            queryWrapper.like(Clazz::getName,clazz.getName());
        }
        Object beginTime = clazz.getParams().get("beginTime");
        if (Objects.nonNull(beginTime) && beginTime instanceof Date beginDate){
            queryWrapper.gt(Clazz::getCreateTime, beginDate);
        }
        Object endTime = clazz.getParams().get("endTime");
        if (Objects.nonNull(endTime) && endTime instanceof Date endDate){
            queryWrapper.lt(Clazz::getCreateTime, endDate);
        }
        return this.list(queryWrapper);
    }


    /**
     * 检测参数班级名称是否唯一
     * @param clazz
     * @return
     */
    @Override
    public boolean checkConfigKeyUnique(Clazz clazz) {
        LambdaQueryWrapper<Clazz> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Clazz::getName, clazz.getName());
        return this.count(queryWrapper) > 0;
    }
}
