package com.zhilian.mybatis_plus.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.google.common.collect.Lists;
import com.zhilian.common.core.utils.StringUtils;
import com.zhilian.mybatis_plus.domain.Clazz;
import com.zhilian.mybatis_plus.domain.Student;
import com.zhilian.mybatis_plus.domain.response.StudentRes;
import com.zhilian.mybatis_plus.mapper.StudentMapper;
import com.zhilian.mybatis_plus.service.StudentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @version:
 * @Author: LiYuan
 * @description:
 * @date: 2024/3/25  15:13
 */
@Service
public class StudentServiceImpl extends ServiceImpl<StudentMapper, Student> implements StudentService {

    @Autowired
    private StudentMapper studentMapper;
    @Autowired
    private ClazzServiceImpl clazzService;

    /**
     * 查询学生列表
     *
     * @param student
     * @return
     */
    @Override
    public List<StudentRes> pageQuery(Student student) {
        //获取班级列表
        List<Clazz> clazzList = clazzService.pageQuery(new Clazz() {{
            setId(student.getTClazz());
        }});
        //获取学生列表
        LambdaQueryWrapper<Student> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(student.getName())) {
            queryWrapper.like(Student::getName, student.getName());
        }
        if (StringUtils.isNotNull(student.getTClazz()) && 0 != student.getTClazz()) {
            queryWrapper.like(Student::getTClazz, student.getTClazz());
        }
        Object beginTime = student.getParams().get("beginTime");
        if (Objects.nonNull(beginTime) && beginTime instanceof Date beginDate) {
            queryWrapper.gt(Student::getCreateTime, beginDate);
        }
        Object endTime = student.getParams().get("endTime");
        if (Objects.nonNull(endTime) && endTime instanceof Date endDate) {
            queryWrapper.lt(Student::getCreateTime, endDate);
        }
        List<Student> list = this.list(queryWrapper);

        //将学生对象与班级对象进行关联
        List<StudentRes> studentRes = list.stream().map(stu -> {
            StudentRes res = new StudentRes();
            Long tClazz = stu.getTClazz();
            Optional<Clazz> foundClazz = clazzList.stream().filter(clazz -> Objects.equals(clazz.getId(), tClazz)).findFirst();

            //未找到班级对象则说明脏数据出现
            if (!foundClazz.isPresent()) {
                throw new RuntimeException("班级数据异常");
            }
            Clazz targetClass = foundClazz.get();
            res.setStudent(stu);
            res.setClazz(targetClass);
            return res;
        }).collect(Collectors.toList());

        return studentRes;
    }

    /**
     * 检测参数学生名称是否唯一
     * @param student
     * @return
     */
    @Override
    public boolean checkConfigKeyUnique(Student student) {
        LambdaQueryWrapper<Student> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Student::getName, student.getName());
        return this.count(queryWrapper) > 0;
    }


}
